[![Build Status](https://travis-ci.org/dilawar/dilawar.svg?branch=master)](https://travis-ci.org/dilawar/dilawar) [![PyPI version](https://badge.fury.io/py/dilawar.svg)](https://badge.fury.io/py/dilawar)

# Dilawar

Personal library 
Collections of helper functions.
